@@ -6,16 +6,16 @@ use warnings;
 #use Log::Any '$log';
 
 use File::Spec;
-use Perinci::Access::InProcess;
+use Perinci::Access::Perl;
 #use SHARYANTO::Array::Util qw(match_array_or_regex); # we'll just use ~~
 use Test::Builder;
 use Test::More ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 my $Test = Test::Builder->new;
 # XXX is cache_size=0 really necessary?
-my $Pa = Perinci::Access::InProcess->new(load=>0, cache_size=>0);
+my $Pa = Perinci::Access::Perl->new(load=>0, cache_size=>0);
 
 sub import {
     my $self = shift;
@@ -111,7 +111,7 @@ sub metadata_in_module_ok {
     $Test->subtest(
         $msg,
         sub {
-            my $uri = "/$module/"; $uri =~ s!::!/!g;
+            my $uri = "pl:/$module/"; $uri =~ s!::!/!g;
 
             if ($opts{test_package_metadata} &&
                     !($module ~~ $opts{exclude_packages})) {
@@ -279,7 +279,7 @@ Test::Rinci - Test Rinci metadata
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
